package com.four.system.api;

import org.apache.ibatis.annotations.Param;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestHeader;
import com.four.common.core.constant.SecurityConstants;
import com.four.common.core.constant.ServiceNameConstants;
import com.four.common.core.domain.R;
import com.four.system.api.domain.SysUser;
import com.four.system.api.factory.RemoteUserFallbackFactory;
import com.four.system.api.model.LoginUser;

/**
 * 用户服务
 *
 * @author ruoyi
 */
@FeignClient(contextId = "remoteUserService", value = ServiceNameConstants.SYSTEM_SERVICE, fallbackFactory = RemoteUserFallbackFactory.class)
public interface RemoteUserService
{

    /**
     * 通过用户名查询用户信息
     *
     * @param email 用户名
     * @param source 请求来源
     * @return 结果
     */

    @GetMapping("/user/infoByEmail/{email}")
    public R<LoginUser> getUserInfoByEmail(@PathVariable("email") String email,@RequestHeader(SecurityConstants.FROM_SOURCE)String source);



    /**
     * 通过用户名查询用户信息
     *
     * @param userName 用户名
     * @param source 请求来源
     * @return 结果
     */
    @GetMapping("/user/info/{userName}")
    public R<LoginUser> getUserInfo(@PathVariable("userName") String userName, @RequestHeader(SecurityConstants.FROM_SOURCE) String source);



    /**
     * 注册用户信息
     *
     * @param sysUser 用户信息
     * @param source 请求来源
     * @return 结果
     */
    @PostMapping("/user/register")
    public R<Boolean> registerUserInfo(@RequestBody SysUser sysUser, @RequestHeader(SecurityConstants.FROM_SOURCE) String source);
}
